make_a_data_dic: make a simple data dictionary

Description Usage Arguments Author(s) Examples

View source: R/make_a_data_dic.R

Description

The output will be a simple data dictionary with outputs 'var_names', 'var_type', 'no_of_unique_values', 'sample_values'.

Usage

1
make_a_data_dic(a_df, var_of_interest = 1:dim(a_df)[2])

Arguments

a_df

A dataframe

var_of_interest

Numeric positions of interesting variables, and the default is to choose all the variables

Author(s)

Lingyun (Larry) Zhang lyzhang10@gmail.com

Examples

1
2
3
4
5
6
7
temp_df <-
  data.frame(a = 1:10,
             b = NA,
             d = c(1:9, NA),
             e = c(letters[1:8], NA, NA),
             stringsAsFactors = FALSE)
x <- make_a_data_dic(temp_df)

zhanglynz/dfexplorer documentation built on May 23, 2021, 8:38 a.m.