Description Usage Arguments Author(s) Examples
View source: R/make_a_data_dic.R
The output will be a simple data dictionary with outputs 'var_names', 'var_type', 'no_of_unique_values', 'sample_values'.
1 | make_a_data_dic(a_df, var_of_interest = 1:dim(a_df)[2])
|
a_df |
A dataframe |
var_of_interest |
Numeric positions of interesting variables, and the default is to choose all the variables |
Lingyun (Larry) Zhang lyzhang10@gmail.com
1 2 3 4 5 6 7 | temp_df <-
data.frame(a = 1:10,
b = NA,
d = c(1:9, NA),
e = c(letters[1:8], NA, NA),
stringsAsFactors = FALSE)
x <- make_a_data_dic(temp_df)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.